@@ -1,5 +1,5 @@
 use typenum::U1;
-use std::ops::Add;
+use core::ops::Add;
 use super::ArrayLength;
 
 /// Helper trait for `arr!` macro
@@ -25,7 +25,7 @@ macro_rules! arr_impl {
         use generic_array::typenum::U0;
         use generic_array::GenericArray;
         use generic_array::arr::Inc;
-        GenericArray::<$T, $N>::from_slice(&[$($x),*])
+        GenericArray::<$T, $N>::clone_from_slice(&[$($x),*])
     });
     ($T:ty; $N:ty, [], [$x1:expr]) => (
         arr_impl!($T; Inc<$T, $N>, [$x1], [])
@@ -42,10 +42,12 @@ macro_rules! arr_impl {
 }
 
 /// Macro allowing for easy generation of Generic Arrays.
+/// Example: `let test = arr![u32; 1, 2, 3];`
 #[macro_export]
 macro_rules! arr {
     ($T:ty; $($x:expr),*) => (
         arr_impl!($T; U0, [], [$($x),*])
     );
-    ($($x:expr,)*) => (arr![$($x),*])
+    ($($x:expr,)+) => (arr![$($x),*]);
+    () => ("""Macro requires a type, e.g. `let array = arr![u32; 1, 2, 3];`")
 }
